0.3.11      (2019-11-21)
-----------------------

### Fixes

* Fixes some layer's export/import mistakes

0.3.10      (2019-11-20)
-----------------------

### Improves

* Add layer_dump and layer_load_dump management command to save and restore layers

0.3.9      (2019-11-19)
-----------------------

### Improves

* Add default layer activation support
* Add layer_dump and layer_load_dump management command to save and restore layers

0.3.8      (2019-11-13)
-----------------------

### Fix

* Deep layer groups raises an error

0.3.7      (2019-11-12)
-----------------------

### Fix

* slug can now be modified and is optionnal

### Improves

* Add default layer activation support

0.3.6      (2019-11-07)
-----------------------

### Fix

* Fix geolayer urls double dash

0.3.5      (2019-11-06)
-----------------------

### Improves

* Set correct permission classes to viewsets

0.3.4      (2019-11-06)
-----------------------

### Fixes

* Fix geostore namespace that is not necessary anymore

0.3.3      (2019-11-06)
-----------------------

### Fixes

* Add Manifest

0.3.2      (2019-11-05)
-----------------------

### Fixes

* Fix url namespace of geostore

0.3.1      (2019-11-05)
-----------------------

### Improves

* Integrate terra permissions mecanism

0.3.0      (2019-10-18)
-----------------------

### Release

* First release
